@@ -66,7 +66,7 @@ class Tier(object):
             runlist = '{"run_list":["recipe[webslave::deploy_%s]"]}' % (args.module)
             chef_command = "echo '%s' > /tmp/runlist; sudo chef-client -j /tmp/runlist" % (runlist)
 
-        knife.reap_instances()
+        knife.reap_instances(args)
         #Entering critical region. Interruption in this region causes a lot of grief
         #and manual merging of chef version files is required
         signal.signal(signal.SIGINT, signal.SIG_IGN)
